Setup
======

Installation
-------------

The latest stable release or development release can be installed from PyPI.


**Pip**

Connect is on PyPi and can be installed using pip. The below will install the latest stable release
of the package.

::

   pip install credoai-connect

The latest development version can also be installed directly from github.

::
